# BBM92_CW
This project is an implementation of the model laid out in [Neumann et al.](https://link.aps.org/doi/10.1103/PhysRevA.104.022406)
The model treats a Continuous Wave (CW) source of photon pairs that are perfectly correlated in time, 
and formalises what the expected asymptotic secure key rate (AKR) is if you use them to perform passive BBM92.

The package is meant to calculate the optimal brightness, coincidence window and corresponding AKR for a given link loss.

# Examples
[see here](https://github.com/Thomas-Jaeken/BBM92_CW)
